@@ -126,7 +126,7 @@ MainWindow::MainWindow(QWidget *parent) :
   m_pbmonitor_style="QPushButton{background-color: #00ff00; \
       border-style: outset; border-width: 1px; border-radius: 5px; \
       border-color: black; min-width: 5em; padding: 3px;}";
-  m_pbmonitor_style2="QPushButton{background-color: #00ffff; \
+  m_pbmonitor_style2="QPushButton{background-color: #ffff00; \
       border-style: outset; border-width: 1px; border-radius: 5px; \
       border-color: black; min-width: 5em; padding: 3px;}";
   m_pbAutoOn_style="QPushButton{background-color: red; \
@@ -179,6 +179,20 @@ MainWindow::MainWindow(QWidget *parent) :
     f.close();
   }
 
+// Read items for fAddComboBox
+  ui->fAddComboBox->addItem (0);
+  ui->fAddComboBox->setItemText(0, QString::number(m_fAdd));
+  QFile g("fadd.txt");
+  QTextStream stream(&g);
+  if(g.open (QIODevice::ReadOnly | QIODevice::Text)) {
+    while (!stream.atEnd()) {
+      QString fAddline = stream.readLine();
+      if (fAddline != "") ui->fAddComboBox->addItem (fAddline);
+    }
+    stream.flush();
+    g.close();
+  }
+
   if(ui->actionLinrad->isChecked()) on_actionLinrad_triggered();
   if(ui->actionCuteSDR->isChecked()) on_actionCuteSDR_triggered();
   if(ui->actionAFMHot->isChecked()) on_actionAFMHot_triggered();
@@ -187,6 +201,9 @@ MainWindow::MainWindow(QWidget *parent) :
   connect (m_wide_graph_window.get (), &WideGraph::freezeDecode2, this, &MainWindow::freezeDecode);
   connect (m_wide_graph_window.get (), &WideGraph::f11f12, this, &MainWindow::bumpDF);
 
+  //default freq at startup for Doppler and Tsky  
+  datcom_.fcenter = 1296.150;
+  
   // only start the guiUpdate timer after this constructor has finished
   QTimer::singleShot (0, [=] {
                            m_gui_timer->start(100); //Don't change the 100 ms!
@@ -239,6 +256,7 @@ void MainWindow::writeSettings()
   settings.setValue("SaveAll",ui->actionSave_all->isChecked());
   settings.setValue("SaveDecoded",ui->actionSave_decoded->isChecked());
   settings.setValue("ContinuousWaterfall",ui->continuous_waterfall->isChecked());
+  settings.setValue("FaddControls",ui->actionFadd_controls->isChecked());
   settings.setValue("NB",m_NB);
   settings.setValue("NBslider",m_NBslider);
   settings.setValue("MaxDrift",ui->sbMaxDrift->value());
@@ -289,6 +307,7 @@ void MainWindow::readSettings()
   ui->actionSave_all->setChecked(settings.value("SaveAll",false).toBool());
   ui->actionSave_decoded->setChecked(settings.value("SaveDecoded",false).toBool());
   ui->continuous_waterfall->setChecked(settings.value("ContinuousWaterfall",false).toBool());
+  ui->actionFadd_controls->setChecked(settings.value("FaddControls",false).toBool());
   m_saveAll=ui->actionSave_all->isChecked();
   m_saveDecoded=ui->actionSave_decoded->isChecked();
   if(m_saveAll) {
@@ -317,6 +336,10 @@ void MainWindow::readSettings()
   }
   m_w3szUrl=settings.value("w3szUrl",true).toBool();    //liveCQ
   m_otherUrl=settings.value("otherUrl","").toString();  //liveCQ
+  ui->fAddComboBox->setVisible(ui->actionFadd_controls->isChecked());
+  ui->fAdd_label->setVisible(ui->actionFadd_controls->isChecked());
+  ui->pbSet->setVisible(ui->actionFadd_controls->isChecked());
+  ui->pbAdd->setVisible(ui->actionFadd_controls->isChecked());
 }
 
 //-------------------------------------------------------------- dataSink()
@@ -487,6 +510,11 @@ void MainWindow::on_actionSettings_triggered()
       soundInThread.setNrx(1);
       soundInThread.start(QThread::HighestPriority);
     }
+
+    if (ui->fAddComboBox->isVisible()) {
+      ui->fAddComboBox->setItemText(0, QString::number(m_fAdd));
+      ui->fAddComboBox->setCurrentIndex(0);
+    }
   }
 }
 
@@ -1003,9 +1031,8 @@ void MainWindow::decodeBusy(bool b)                             //decodeBusy()
 
 void MainWindow::CreateLiveCQ(QStringList cqliveText)
 {
-  if (cqliveText.size() == 0) return;  //return if cqliveText is empty
-
-  //if(cqliveText.size() == 0) cqliveText << "043800  57.379  55.0  2.93  -11  CQ ES3RF KO29" << "043830  159.638  157.3  2.18  -12  QRZ WA3GFZ FN20" << "043800  67.507  65.2  3.08  -17  W2ZQ PA3HDG JO31" << "043830  9.356  7.0  2.93  -13  CQ IQ2DB JN45";
+//return if cqliveText is empty or data were read from disk.
+  if ((m_diskData && m_myCall.toUpper() != "W3SZ" && m_myCall.toUpper() != "DL3WDG") or (cqliveText.size() == 0)) return;
 
   QStringList cqliveFinalText;
   QStringList oldFile;
@@ -1016,67 +1043,190 @@ void MainWindow::CreateLiveCQ(QStringList cqliveText)
   QString bandFreq = bandInfo.at(0);
   QString theDate = ui->labUTC->text().trimmed().mid(0,12);
   QList<QStringList> decodeList;
+  bool strOK = false;
 
   for (const QString &item : cqliveText) {
     QString line = " ";
     QStringList thePostLine;
-    line = line.repeated(100);
+    line = line.repeated(100);  //.replace("<","").replace(">","");
     QStringList thePieces;
-
     thePieces = item.split(" ",SkipEmptyParts);
-    if((thePieces.at(6) == "CQ" || thePieces.at(6) == "QRZ" || thePieces.at(6) == "CQV" ||  thePieces.at(6) == "CQH" ||  thePieces.at(6) == "QRT") && m_myCall.length() >=3 && m_myGrid.length()>=4) {
-      //extract Fsked freq and format to 3 digits no decimals
-      QString theMsg = thePieces.at(6) + " " + thePieces.at(7) + " " +thePieces.at(8);
-      QStringList thekHz = thePieces.at(9).split(".");
-      int rxFreq = freqOffset + thekHz.at(1).toInt(&ok);
-      // int rxFreq = freqOffset + 100 * thekHz.at(1).toInt(&ok);
-      int skedFreq;
-      QString skedFreqString;
-      if (rxFreq <= freqOffset + 500) {
-        skedFreq = thekHz.at(0).toInt(&ok);
-      } else {
-        skedFreq = thekHz.at(0).toInt(&ok) + 1;
-        rxFreq=rxFreq - 1000;
-      }
-      skedFreqString = QString::number(skedFreq).rightJustified(3,'0');
-      QString mode = "0 Q65-" + thePieces.at(5);
-      line.insert(0,bandFreq + "." + skedFreqString);
-      line.insert(10,QString::number(rxFreq));
-      line.insert(15,"0");
-      line.insert(18,thePieces.at(0));
-      line.insert(26,thePieces.at(3));
-      line.insert(32,thePieces.at(4));
-      line.insert(36,theMsg);
-      line.insert(55,mode);
-      line.insert(67,m_myGrid.toUpper());
-      line.insert(74,"Q");
-      line.insert(76,theDate);
-      line.insert(88,m_myCall.toUpper());
-      cqliveFinalText << line.trimmed();
+    int rxFreq = 0.0;
+    if((thePieces.at(6) == "CQ" || thePieces.at(6) == "QRZ" || thePieces.at(6) == "CQV" ||  thePieces.at(6) == "CQH" ||  thePieces.at(6) == "QRT") && m_myCall.length() >=3 && m_myGrid.length()>=4  ) {
+      try {
+        //extract Fsked freq and format to 3 digits no decimals
+        QString theMsg;
+        QString theCall;
+        QString theGrid;
+        QStringList thekHz;
+        int nWords=thePieces.length();
+        if(nWords==9) {
+          // Handle CQ CALL messages that do not include a locator
+          if(thePieces.at(6)==NULL or thePieces.at(7)==NULL or thePieces.at(8)==NULL) continue;
+          theCall = thePieces.at(7);
+          bool isCall = testCall(theCall);
+          if(!isCall) continue;
+          theGrid = "--";
+          theMsg = thePieces.at(6) + " " + theCall;
+          thekHz = thePieces.at(8).split(".");
+          rxFreq = freqOffset + thekHz.at(1).toInt(&ok);
+        // int rxFreq = freqOffset + 100 * thekHz.at(1).toInt(&ok);
+          if (!ok) continue;
+        } else if(nWords==10) {
+          // Handle CQ CALL GRID --or-- CQ XXX CALL
+          if(thePieces.at(6)==NULL or thePieces.at(7)==NULL or thePieces.at(8)==NULL or thePieces.at(9)==NULL) continue;
+          // Test for callsign at thePieces.at(7)
+          theCall = thePieces.at(7);
+          bool isCall = testCall(theCall);
+          // Handle CQ CALL GRID
+          if(isCall) {
+            theGrid = thePieces.at(8);
+            theMsg = thePieces.at(6) + " " + theCall + " " + theGrid;
+          }
+          // Handle CQ XXX CALL
+          else {
+            theCall = thePieces.at(8);
+            isCall = testCall(theCall);
+            if(!isCall) continue;
+            theGrid = "--";
+            theMsg = thePieces.at(6) + " " + theCall;
+          }
+          thekHz = thePieces.at(9).split(".");
+          rxFreq = freqOffset + thekHz.at(1).toInt(&ok);
+        // int rxFreq = freqOffset + 100 * thekHz.at(1).toInt(&ok);
+          if (!ok) continue;
+          // Handle CQ XXX CALL GRID
+        } else if (nWords==11) {
+           if(thePieces.at(6)==NULL or thePieces.at(7)==NULL or thePieces.at(8)==NULL or thePieces.at(9)==NULL or thePieces.at(10)==NULL) continue;
+          theCall = thePieces.at(8);
+          bool isCall = testCall(theCall);
+          if(!isCall) continue;
+          theGrid = thePieces.at(9);
+          theMsg = thePieces.at(6) + " " + theCall + " " + theGrid;
+          thekHz = thePieces.at(10).split(".");
+          rxFreq = freqOffset + thekHz.at(1).toInt(&ok);
+        // int rxFreq = freqOffset + 100 * thekHz.at(1).toInt(&ok);
+          if (!ok) continue;
+        }
+        else continue;
+        strOK = true;
+        int skedFreq;
+        QString skedFreqString;
+        if (rxFreq <= freqOffset + 500) {
+          skedFreq = thekHz.at(0).toInt(&ok);
+        } else {
+          skedFreq = thekHz.at(0).toInt(&ok) + 1;
+          rxFreq=rxFreq - 1000;
+        }
+        skedFreqString = QString::number(skedFreq).rightJustified(3,'0');
+        QString mode = "0 Q65-" + thePieces.at(5);
+        line.insert(0,bandFreq + "." + skedFreqString);
+        line.insert(10,QString::number(rxFreq));
+        line.insert(15,"0");
+        line.insert(18,thePieces.at(0));
+        line.insert(26,thePieces.at(3));
+        line.insert(32,thePieces.at(4));
+        line.insert(36,theMsg);
+        line.insert(55,mode);
+        line.insert(67,m_myGrid.toUpper());
+        line.insert(74,"Q");
+        line.insert(76,theDate);
+        line.insert(88,m_myCall.toUpper());
+        cqliveFinalText << line.trimmed();
+        //qDebug () << "cqliveFinalText is: " << cqliveFinalText;
 
-      thePostLine.insert(0, bandFreq + "." + skedFreqString);  //skedfreq
-      thePostLine.insert(1, QString::number(rxFreq)); //rxfreq
-      thePostLine.insert(2, "--"); //rpol
-      thePostLine.insert(3,thePieces.at(0)); //utc HHmmSS
-      thePostLine.insert(4,thePieces.at(3)); //dt
-      thePostLine.insert(5, thePieces.at(4)); //dB
-      thePostLine.insert(6, "Q65-" + thePieces.at(5)); //Q65 submode
-      thePostLine.insert(7, thePieces.at(6)); //msg type
-      thePostLine.insert(8, thePieces.at(7)); //dx call
-      thePostLine.insert(9, thePieces.at(8)); //dx grid
-      thePostLine.insert(10, m_myGrid.toUpper()); //myGrid
-      thePostLine.insert(11, theDate);  //the date
-      thePostLine.insert(12, m_myCall.toUpper()); //myCall
-      thePostLine.insert(13, "--"); //txpol
-      decodeList.append(thePostLine);
+        thePostLine.insert(0, bandFreq + "." + skedFreqString);  //skedfreq
+        thePostLine.insert(1, QString::number(rxFreq)); //rxfreq
+        thePostLine.insert(2, "--"); //rpol
+        thePostLine.insert(3,thePieces.at(0)); //utc HHmmSS
+        thePostLine.insert(4,thePieces.at(3)); //dt
+        thePostLine.insert(5, thePieces.at(4)); //dB
+        thePostLine.insert(6, "Q65-" + thePieces.at(5)); //Q65 submode
+        thePostLine.insert(7, thePieces.at(6)); //msg type
+        thePostLine.insert(8, theCall); //dx call
+        thePostLine.insert(9, theGrid); //dx grid
+        thePostLine.insert(10, m_myGrid.toUpper()); //myGrid
+        thePostLine.insert(11, theDate);  //the date
+        thePostLine.insert(12, m_myCall.toUpper()); //myCall
+        thePostLine.insert(13, "--"); //txpol
+        decodeList.append(thePostLine);
+        //qDebug () << "thePostLine is: " << thePostLine;
+      }
+      catch (const std::exception& e) {
+          // Handle standard C++ exceptions
+          QMessageBox::critical(this, "Exception", "Exception at line 1116 MainWindow::CreateLiveCQ " + QString::fromStdString(e.what())); 
+      }
+      catch (...) {
+          // Handle any other type of exception
+          QMessageBox::critical(this, "Exception", "Unknown Exception at line 1121 MainWindow::CreateLiveCQ"); 
+      }
+  }
+}
+  if(strOK) {
+  sendLiveCQData(decodeList);
+  }
+}
+
+bool MainWindow::testCall(QString w)
+{
+// Check "callsign" to see if it could be a valid standard callsign or a valid
+// compound callsign.
+// Return a logical "call ok" indicator.
+  if(w.indexOf('.') >= 0) return false;
+  if(w.indexOf('+') >= 0) return false;
+  if(w.indexOf('-') >= 0) return false;
+  if(w.indexOf('?') >= 0) return false;
+  w = w.replace('<',"");
+  w = w.replace('>',""); 
+  int n1=w.length();
+  if(n1 > 11) return false;
+  //qDebug() << "Line 1186 w is: " << w << " and i0 is: " << i0 << " and n1 is: " << n1 << " and call is: " << w;
+  QString bc = QString();
+  QStringList wSplit = w.split("/");
+  if(wSplit.length() > 1) {
+    if(wSplit.at(0).length() > wSplit.at(1).length()) {
+      bc = wSplit.at(0);
+    }
+    else {
+      bc = wSplit.at(1);
     }
   }
+  else {
+    bc = w;
+  }
+  int nbc=bc.trimmed().length();
+  if(nbc > 8) return false;  //Base call should have no more than 8 characters  e.g. YW18FIFA
 
-  sendLiveCQData(decodeList);
+// One of first two characters (c1 or c2) must be a letter
+  if((!bc[0].isLetter()) && (!bc[1].isLetter())) return false;
+// Real calls don't start with Q, but we'll allow the placeholder
+// callsign QU1RK to be considered a standard call:
+  if(bc[0]=='Q' && bc.mid(0,5) != "QU1RK") return false;
+
+// Must have a digit in 2nd or 3rd or 4th position
+  int i1=0;
+  if(bc[1].isDigit()) i1=1;
+  if(bc[2].isDigit()) i1=2;
+  if(bc[3].isDigit()) i1=3;
+  if(i1==0) return false;
+
+// Callsign must have a suffix of 1-4 letters e.g. YW18FIFA
+  if(i1==nbc) return false;
+  int n=0;
+  QChar j=QChar();
+  for (int i=i1+1; i<=nbc-1; ++i) {
+     j=bc[i];
+     if(j<QChar('A') || j > QChar('Z')) return false;
+     n=n+1;
+  }
+  if(n >= 1 && n <= 4) return true;
+  
+  return false;  
 }
 
 void MainWindow::sendLiveCQData(QList<QStringList>decodeList)
 {
+  if (decodeList.size() == 0) return;
   QString theUrl;
   if(m_w3szUrl) {
     theUrl = w3szUrlAddr;
@@ -1109,20 +1259,35 @@ void MainWindow::sendLiveCQData(QList<QStringList>decodeList)
 	  QNetworkReply *reply = manager->post(request,postByteArray);		
 	  QObject::connect(reply, &QNetworkReply::finished, this, &MainWindow::handleReply);
     }
-    catch(...)
-    {
+    catch (const std::exception& e) {
+        // Handle standard C++ exceptions
+        QMessageBox::critical(this, "Exception", "Exception at line 1165 MainWindow::sendLiveCQData " + QString::fromStdString(e.what()));   
+    }
+    catch (...) {
+        // Handle any other type of exception
+        QMessageBox::critical(this, "Exception", "Unknown Exception at line 1170 MainWindow::sendLiveCQData");   
     }
   }
 }
 
 void MainWindow::handleReply()
 {
+  try {
     QNetworkReply *reply = qobject_cast<QNetworkReply*>(sender());
     if (reply->error() == QNetworkReply::NoError) {
 		qDebug() << reply->readAll();
     } else {
 		qDebug() << reply->errorString();
     }
+  }
+    catch (const std::exception& e) {
+        // Handle standard C++ exceptions
+        QMessageBox::critical(this, "Exception", "Exception at line 1188 MainWindow::handleReply " + QString::fromStdString(e.what()));   
+    }
+    catch (...) {
+        // Handle any other type of exception
+        QMessageBox::critical(this, "Exception", "Unknown Exception at line 1193 MainWindow::handleReply");   
+    }
 }
 
 
@@ -1372,4 +1537,58 @@ void MainWindow::on_actionExport_wav_file_at_fQSO_30b_triggered()
 {
   datcom_.newdat=0;
   datcom_.nagain=4;
-  decode();}
+  decode();
+}
+
+void MainWindow::on_actionFadd_controls_triggered()
+{
+  if (ui->actionFadd_controls->isChecked()) {
+    ui->fAddComboBox->setVisible(true);
+    ui->fAdd_label->setVisible(true);
+    ui->pbSet->setVisible(true);
+    ui->pbAdd->setVisible(true);
+  } else {
+    ui->fAddComboBox->setVisible(false);
+    ui->fAdd_label->setVisible(false);
+    ui->pbSet->setVisible(false);
+    ui->pbAdd->setVisible(false);
+  }
+}
+
+void MainWindow::on_fAddComboBox_activated()
+{
+  if (ui->fAddComboBox->isVisible() && ui->fAddComboBox->currentText() != "") {
+    m_fAdd=ui->fAddComboBox->currentText().toDouble();
+    soundInThread.setFadd(m_fAdd);
+    ui->decodedTextBrowser->append("Setting Fadd to " + QString::number(m_fAdd) + " MHz");
+  }
+}
+
+void MainWindow::on_pbSet_clicked()
+{
+  m_fAdd=ui->fAddComboBox->currentText().toDouble();
+  soundInThread.setFadd(m_fAdd);
+  ui->decodedTextBrowser->append("Setting Fadd to " + QString::number(m_fAdd) + " MHz");
+}
+
+void MainWindow::on_pbAdd_clicked()
+{
+  m_fAdd=ui->fAddComboBox->currentText().toDouble();
+  if (ui->fAddComboBox->currentText() != "") {
+    QFile g("fadd.txt");
+    if(g.open(QIODevice::Text | QIODevice::Append)) {
+      QString addedEntry = (ui->fAddComboBox->currentText());
+      QTextStream out(&g);
+      out << addedEntry <<
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+          endl
+#else
+          Qt::endl
+#endif
+          ;
+      g.close();
+      if (ui->fAddComboBox->findText(addedEntry) < 0) ui->fAddComboBox->addItem (QString::number(m_fAdd));
+      ui->decodedTextBrowser->append("Adding " + QString::number(m_fAdd) + " to file fadd.txt");
+    }
+  }
+}
