@@ -48,7 +48,7 @@ namespace
      , {"RS", QT_TRANSLATE_NOOP ("LogQSO", "Rain scatter")}
      , {"SAT", QT_TRANSLATE_NOOP ("LogQSO", "Satellite")}
      , {"TEP", QT_TRANSLATE_NOOP ("LogQSO", "Trans-equatorial")}
-     , {"TR", QT_TRANSLATE_NOOP ("LogQSO", "Troposheric ducting")}
+     , {"TR", QT_TRANSLATE_NOOP ("LogQSO", "Tropospheric ducting")}
     };
   struct SatMode
   {
@@ -171,7 +171,7 @@ void LogQSO::loadSettings ()
   QString comments_location;  // load the content of comments.txt file to the comments combo box
   QDir dataPath {QStandardPaths::writableLocation (QStandardPaths::DataLocation)};
   comments_location = dataPath.exists("comments.txt") ? dataPath.absoluteFilePath("comments.txt") : m_config->data_dir ().absoluteFilePath ("comments.txt");
-  QFile file2 = {comments_location};
+  QFile file2 {comments_location};
   QTextStream stream2(&file2);
   if(file2.open (QIODevice::ReadOnly | QIODevice::Text)) {
       while (!stream2.atEnd()) {
@@ -199,7 +199,11 @@ void LogQSO::storeSettings () const
   m_settings->setValue ("SaveSatMode", ui->cbSatMode->isChecked ());
   m_settings->setValue ("SaveFreqRx", ui->cbFreqRx->isChecked ());
   m_settings->setValue ("TxPower", m_txPower);
-  m_settings->setValue ("LogComments", m_comments);
+  if (ui->cbComments->isChecked ()) {
+    m_settings->setValue ("LogComments", m_comments);
+  } else {
+    m_settings->setValue ("LogComments", "");
+  }
   m_settings->setValue ("PropMode", ui->comboBoxPropMode->currentData ());
   m_settings->setValue ("Satellite", ui->comboBoxSatellite->currentData ());
   m_settings->setValue ("SatMode", ui->comboBoxSatMode->currentData ());
@@ -533,7 +537,7 @@ void LogQSO::on_addButton_clicked()
   if (m_comments_temp != "") {
       QString comments_location = m_config->writeable_data_dir().absoluteFilePath("comments.txt");
       if(QFileInfo::exists(m_config->writeable_data_dir().absoluteFilePath("comments.txt"))) {
-      QFile file2 = {comments_location};
+      QFile file2 {comments_location};
         if (file2.open(QIODevice::WriteOnly | QIODevice::Text | QIODevice::Append)) {
             QTextStream out(&file2);
             out << m_comments_temp              // append new line to comments.txt
@@ -550,7 +554,7 @@ void LogQSO::on_addButton_clicked()
                                            "\"comments.txt\" from your log directory");
         }
       } else {
-          QFile file2 = {comments_location};
+          QFile file2 {comments_location};
          if (file2.open(QIODevice::WriteOnly | QIODevice::Text | QIODevice::Append)) {
              QTextStream out(&file2);
              out << ("\n" + m_comments_temp)    // create file "comments.txt" and add a blank line
@@ -568,7 +572,7 @@ void LogQSO::on_addButton_clicked()
          }
       }
       ui->comments->clear();               // clear the comments combo box and reload updated content
-      QFile file2 = {comments_location};
+      QFile file2 {comments_location};
       QTextStream stream2(&file2);
       if(file2.open (QIODevice::ReadOnly | QIODevice::Text)) {
           while (!stream2.atEnd()) {
