@@ -95,6 +95,7 @@ class MessageClient;
 class QTime;
 class WSPRBandHopping;
 class HelpTextWindow;
+class EQSL;
 class WSPRNet;
 class SoundOutput;
 class Modulator;
@@ -145,6 +146,7 @@ public slots:
   void setFreq4(int rxFreq, int txFreq);
   void msgAvgDecode2();
   void fastPick(int x0, int x1, int y);
+  void skedFreq(double sf);
 
 private:
   void change_layout (std::size_t) override;
@@ -158,6 +160,8 @@ private slots:
   void initialize_fonts ();
   void ScrollBarPosition(int n);
   void on_actionUse_Dark_Style_triggered (bool checked);
+  void on_actionBand_Buttons_triggered ();
+  void on_actionVHF_UHF_Buttons_triggered ();
   void on_pb160_clicked();
   void on_pb80_clicked();
   void on_pb60_clicked();
@@ -168,9 +172,22 @@ private slots:
   void on_pb15_clicked();
   void on_pb12_clicked();
   void on_pb10_clicked();
+  void on_pb8_clicked();
   void on_pb6_clicked();
   void on_pb2_clicked();
   void on_pb70_clicked();
+  void on_pb50_clicked();
+  void on_pb4_clicked();
+  void on_pb144_clicked();
+  void on_pb220_clicked();
+  void on_pb432_clicked();
+  void on_pb902_clicked();
+  void on_pb23_clicked();
+  void on_pb13_clicked();
+  void on_pb9_clicked();
+  void on_pb5G_clicked();
+  void on_pb10G_clicked();
+  void on_pb24G_clicked();
   void check_button_color();
   void stopWRTimeout();
   void stopWCTimeout();
@@ -202,6 +219,7 @@ private slots:
   void on_autoButton_clicked (bool);
   void on_stopTxButton_clicked();
   void on_stopButton_clicked();
+  void on_pbBandHopping_clicked();
   void on_actionRelease_Notes_triggered ();
   void on_actionFT8_DXpedition_Mode_User_Guide_triggered();
   void on_actionSuperFox_User_Guide_triggered();
@@ -226,6 +244,7 @@ private slots:
   void on_actionDefault_event_logging_triggered();
   void on_actionDiagnostic_mode_triggered();
   void on_actionDisable_event_logging_triggered();
+  void on_actionDownload_EME_Ephemeris_Chart_triggered();
   void on_actionKeyboard_shortcuts_triggered();
   void on_actionSpecial_mouse_commands_triggered();
   void on_actionSolve_FreqCal_triggered();
@@ -263,6 +282,7 @@ private slots:
   void on_ignoreButton_clicked();
   void on_comboBoxCQ_activated ();
   void on_DX_Call_Button_clicked (bool checked);
+  void wheelEvent(QWheelEvent *event) override;
   void mousePressEvent(QMouseEvent *event) override;
   void on_dxCallEntry_textChanged (QString const&);
   void on_dxGridEntry_textChanged (QString const&);
@@ -275,6 +295,7 @@ private slots:
   void read_ignoreList();
   void addCallsignToignoreList();
   void on_actionErase_Ignore_List_triggered();
+  void read_ALLCALL7();
   void remove_old_files(const QString &directoryPath, int daysOld);
   void on_actionJT9_triggered();
   void on_actionJT65_triggered();
@@ -288,6 +309,39 @@ private slots:
   void on_actionQuickDecode_toggled (bool);
   void on_actionMediumDecode_toggled (bool);
   void on_actionDeepestDecode_toggled (bool);
+
+  //ft8md
+  void on_actionDecFT8cycles1_triggered();
+  void on_actionDecFT8cycles2_triggered();
+  void on_actionDecFT8cycles3_triggered();
+  void on_actionRXfLow_triggered();
+  void on_actionRXfMedium_triggered();
+  void on_actionRXfHigh_triggered();
+  void on_actionMTAuto_triggered();
+  void on_actionMT1_triggered();
+  void on_actionMT2_triggered();
+  void on_actionMT3_triggered();
+  void on_actionMT4_triggered();
+  void on_actionMT5_triggered();
+  void on_actionMT6_triggered();
+  void on_actionMT7_triggered();
+  void on_actionMT8_triggered();
+  void on_actionMT9_triggered();
+  void on_actionMT10_triggered();
+  void on_actionMT11_triggered();
+  void on_actionMT12_triggered();
+  void on_actionFT8SensMin_toggled(bool checked);
+  void on_actionlowFT8thresholds_toggled(bool checked);
+  void on_actionFT8subpass_toggled(bool checked);
+  void on_actionStartTwoStage_toggled(bool checked);
+  void on_actionStartThreeStage_toggled(bool checked);
+  void on_actionStartEarly_toggled(bool checked);
+  void on_actionStartNormal_toggled(bool checked);
+  void on_actionStartLate_toggled(bool checked);
+  void on_actionFT8WidebandDXCallSearch_toggled(bool checked);
+  void on_actionUse_multithreaded_FT8_decoder_triggered(bool checked);
+  //ft8md
+
   void bumpFqso(int n);
   void on_actionErase_ALL_TXT_triggered();
   void on_reset_cabrillo_log_action_triggered ();
@@ -410,6 +464,10 @@ private slots:
   void update_tx5(const QString &qsy_text);
   void reply_tx5(const QString &qsy_text);
   void setQSYMessageCreatorStatus(const bool &QSYMessageCreatorValue);
+  void on_rbFixedTone_toggled(bool b);
+  void on_rbEchoMessage_toggled(bool b);
+  void on_rbEchoCW_toggled(bool b);
+  void on_leEchoMessage_textChanged();
 
 private:
   Q_SIGNAL void initializeAudioOutputStream (QAudioDeviceInfo,
@@ -450,6 +508,7 @@ private:
   void configActiveStations();
   void sfox_tx();
   bool play_DXcall = false;
+  bool play_Wanted = false;
   bool inSettings = false;
 
   QProcessEnvironment const& m_env;
@@ -507,12 +566,19 @@ private:
 
   qint64  m_msErase;
   qint64  m_secBandChanged;
+  qint64  m_msDecStarted; //ft8md
   qint64  m_freqMoon;
   qint64  m_fullFoxCallTime;
+  qint64  m_msEchoTxStart=0;
 
   Frequency m_freqNominal;
   Frequency m_freqNominalPeriod;
   Frequency m_freqTxNominal;
+  quint64 m_msk144basefreq;
+  quint64 m_msk144oldfreq;
+  quint64  m_mslastTX;   //ft8md
+  qint32  m_nlasttx;     //ft8md
+  qint32  m_lapmyc;      //ft8md
   Astro::Correction m_astroCorrection;
   bool m_reverse_Doppler;
 
@@ -522,6 +588,7 @@ private:
   double  m_s6;
   double  m_fDither;
   double  m_fAudioShift;
+  double  m_skedFreq;
 
   float   m_DTtol;
   float   m_t0;
@@ -529,6 +596,7 @@ private:
   float   m_t0Pick;
   float   m_t1Pick;
   float   m_fCPUmskrtd;
+  float   m_tEcho=0;
 
   qint32  m_waterfallAvg;
   qint32  m_ntx;
@@ -538,6 +606,19 @@ private:
   qint32  m_XIT;
   qint32  m_setftx;
   qint32  m_ndepth;
+  qint32  m_ncandthin; //ft8md
+
+  //ft8md
+  qint32  m_nFT8Cycles;
+  qint32  m_nFT8SWLCycles;
+  qint32  m_nFT8RXfSens;
+  qint32  m_ft8threads;
+  qint32  m_ft8Sensitivity;
+  qint32  m_ft8DecoderStart;
+  qint32  m_nsecBandChanged;
+  qint32  m_nFT4depth;
+  //ft8md
+
   qint32  m_sec0;
   qint32  m_RxLog;
   qint32  m_nutc0;
@@ -554,9 +635,6 @@ private:
   qint32  m_secID;
   qint32  m_idleMinutes;
   qint32  m_nSubMode;
-  qint32  m_nSubMode_Q65;
-  qint32  m_nSubMode_JT65;
-  qint32  m_nSubMode_JT4;
   qint32  m_nclearave;
   qint32  m_minSync;
   qint32  m_dBm;
@@ -608,6 +686,27 @@ private:
   bool    m_auto;
   bool    m_restart;
   bool    m_startAnother;
+
+  // start ft8md
+  bool    m_FT8EarlyStart;   
+  bool    m_FT8WideDxCallSearch; 
+  bool    m_skipTx1;
+  bool    m_swl; 
+  bool    m_filter;
+  bool    m_agcc;
+  bool    m_hint;
+  bool	  m_multithreadFT8; 
+  bool 	  m_houndMode;
+  bool    m_commonFT8b;
+  bool	  m_manualDecode;   
+  bool	  m_modeChanged;   
+  bool    m_bMyCallStd;
+  bool    m_bHisCallStd;
+  bool    m_multInst;
+  bool    m_bandChanged;
+  bool 	  m_lasthint; 
+  // end ft8md
+
   bool    m_saveDecoded;
   bool    m_saveAll;
   bool    m_widebandDecode;
@@ -651,6 +750,7 @@ private:
   bool    m_bDoubleClicked;
   bool    m_bCallingCQ;
   bool    m_bAutoReply;
+  QString m_lastloggedcall; //ft8md
   bool    m_bCheckedContest;
   bool    m_bWarnedSplit=false;
   bool    m_bTUmsg;
@@ -712,6 +812,7 @@ private:
   QProcess p4;
 
   WSPRNet *wsprNet;
+  EQSL *Eqsl;
 
   QTimer m_guiTimer;
   QTimer stopWRTimer;               //Wait & Reply
@@ -737,6 +838,7 @@ private:
   QString m_palette;
   QString m_dateTime;
   QString m_mode;
+  QString m_modeTx;//ft8md
   QString m_fnameWE;            // save path without extension
   QString m_rpt;
   QString m_nextRpt;
